from setuptools import setup, find_packages

setup(
    name='namespaced.sneaky',
    version='0.1',
    description='Test namespaced packages with non-root egg-info.',
    author='Tres Seaver',
    author_email='tseaver@palladion.com',
    long_description='Blah, blah.',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['namespaced',],
    install_requires=['setuptools'],
    zip_safe=False,
)



from pkginfo.bdist import BDist
from pkginfo.develop import Develop
from pkginfo.distribution import Distribution
from pkginfo.index import Index
from pkginfo.installed import Installed
from pkginfo.sdist import SDist
from pkginfo.sdist import UnpackedSDist
from pkginfo.utils import get_metadata
from pkginfo.wheel import Wheel



# requirements


def _checkSample(testcase, installed):
    try:
        import pkg_resources
    except ImportError: # no setuptools :(
        pass
    else:
        version = pkg_resources.require('pkginfo')[0].version
        testcase.assertEqual(installed.version, version)
    testcase.assertEqual(installed.name, 'pkginfo')
    testcase.assertEqual(installed.keywords,
                        'distribution sdist installed metadata' )
    testcase.assertEqual(list(installed.supported_platforms), [])

def _checkClassifiers(testcase, installed):
    testcase.assertEqual(list(installed.classifiers),
                         [
      'Intended Audience :: Developers',
      'License :: OSI Approved :: Python Software Foundation License',
      'Operating System :: OS Independent',
      'Programming Language :: Python :: 2.6',
      'Programming Language :: Python :: 2.7',
      'Programming Language :: Python :: 3.2',
      'Programming Language :: Python :: 3.3',
      'Programming Language :: Python :: Implementation :: CPython',
      'Programming Language :: Python :: Implementation :: PyPy',
      'Topic :: Software Development :: Libraries :: Python Modules',
      'Topic :: System :: Software Distribution',
    ])


def _defaultMetadataVersion():
    import sys
    if sys.version_info[:2] > (2, 6):
        return '1.1'
    return '1.0'



from setuptools import setup

setup(
    name='mypackage',
    version='0.1',
    author='Tres Seaver',
    author_email='tseaver@palladion.com',
    url='http://pypi.python.org/pypi/pkginfo',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console (Text Based)',
    ],
)
